@@ -2,6 +2,7 @@
 
 from __future__ import annotations
 
+from .__about__ import __version__
 from .cli import main
 
-__all__ = ["main"]
+__all__ = ["main", "__version__"]
